/**
 * @file label_trash.js
 * 
 * Takes parameters set on the configuration page and invokes floatlabel.js
 */
(function ($) {
  Drupal.behaviors.label_trash_attach = {

    attach: function(context, settings) {

      $(settings.label_trash, context).each(function() {

        // settings is an array of params indexed by CSS input field selector.
        for (var selector in this) {
          var inputs = $(selector);
          var params = this[selector];
          
          inputs.each(function() {
            var placeholder = $(this).attr('placeholder');
            // If the input element does not already have a placeholder,
            // create one based on its neighbouring label element.
            if (!placeholder) {
              var label = $(this).prev('label'); // or siblings() ?
              if (label.length === 0) {
                // The targeted element may live inside a <div>.
                label = $(this).parent().siblings('label');
              }
              placeholder = label.html();
            }
            if (!placeholder) {
              // If after all this we still have no placeholder, end like this:
              $(this).attr('placeholder', Drupal.t('Type here'));
            }
            else {
              // Check whether the float flag is set.
              if (params['label-style']) {
                // Remove the label, floatlable() will create a new one.
                label.remove();
                
                $(this).attr('data-label', placeholder);
                // Deal with placeholders containing HTML, like:
                // 'Title <span class="form-required" title="Field is required.">*</span>'
                var split = placeholder.indexOf('<');
                var placeholder_escaped = split < 0 ? placeholder : placeholder.substring(0, split) + $(placeholder.substring(split)).text();
                $(this).attr('placeholder', placeholder_escaped);

                $(this).floatlabel({
                  labelStartTop: params['floatlabel-offset-top-start'],
                  labelEndTop: params['floatlabel-offset-top-end'],
                  labelClass: params['label-css']['data-class'],
                  slideInput: params['slide-input'],
                  transitionDuration: params['transition-duration'],
                  transitionEasing: params['transition-easing'],
                });
              }
              else {
                // Hide rather than remove, for accessibility.
                label.hide();
              }
            }           
          });
        }
      });
    }
  }
}) (jQuery);
